==> Cosmos.uv3.02.tar.gz: Import/Test/tstaadn.f <==
caadnhadrin.  the monte carlo code hadrin to simulate inelastic hadron-
c1   nucleon interactions at laboratory energies below 5 gev.
c2  k. hanssgen, j. ranft.
cref. in comp. phys. commun. 39 (1986) 37
c   mainprogram for test of hadrin
      dimension anap(60)
      real * 8 aname,zkname,rkname,anap
      integer * 2 ich,ibar,k1,k2,nzk,nrk
      common /namsd/ aname(110),zkname(460),rkname(268)
      common/abltis/am(110),ga(110),tau(110),ich(110)
     *,ibar(110),k1(110),k2(110)
      common /encote/ etest,tnkte
      common/finlsp/ ir ,itr(20),cxr(20),cyr(20),czr(20),elr(20),plr(20)
      integer * 2 nure,ieii,ikii
      common /sp lit/ nzk(460,3),wt(460)
      common /redver/ irii(17),ikii(17),ieii(17),thresh(268)
      common /reac/umo(296),plabf(296),siin(296),wk(5184),nrk(2,268),
     *nure(30,2)
c*** preparation of data for use in hadrin
c*** read input data
c*** n    = type of the projectile particle
c*** ia   = nucleon number of the target nucleon
c*** iz   = charge of the target nucleon
c*** plab = laboratory momentum of the projectile particle (gev/c)
c*** idifd = switch variable (=0: simulation of only one event,
      dimension nf(10)
c---- test example data input
c     data nf/1,14,2,1,6*999/
      data nf/9*25, 999/
      data iz,ia,plab /1,1,2.0/
c---- end of data input
      character*70 ttl
      character*16 capx, capy, capz, cappt
         external blkhd1, blkhd2, blkhd3, blkhd4
         external blkdc1, blkdc2
      open(13,file='c2s5001.#gd.data')
      capx='ptcl code'
      capy='x=(e/e0)'
      capz='lab-rapidity'
      cappt='pt(gev/c)'
      call hadden
      call chanwh
c**** for the output of tables 2 to 5 only, delete therefore "c----"
c**** of the following line
c---- call datesh
c      n=13
       n=1
       plab=5.0
      elab=sqrt(plab**2+am(n)**2)
c     elab=5.0
c     plab=sqrt(elab**2-am(n)**2)
      write(ttl,'('' plab='',f5.1,'' gev; p p; hadrin'')') plab
      pmass=am(n)
      tmass=am(1)
      call kgcm(elab, pmass, tmass, roots, gc)
      call kgtogb(gc, gcb)
      epipmx=(roots**2 -1.88**2 +am(13)**2)/2/roots
      epimmx=(roots**2 -2.02**2 +am(14)**2)/2/roots
c     epi0mx=(roots**2 -1.88**2 +am(23)**2)/2/roots
      write(13) ttl
      write(13) capy, capz,capx
       itta=1
          cx=0.
          cy=0.
          cz=1.
           do   i=1, 50000
              if(mod(i,1000) .eq. 0) then
                  write(*,*) ' i=',i
              endif
              call hadrin(n,plab,elab,cx,cy,cz,itta)
               do   j=1, ir
                 k=itr(j)
c                if(k .eq. 13 .or. k.eq. 14 .or. k .eq. 23) then
                 if(k .eq. 13 .or. k.eq. 14 .or. k .eq. 23) then
                      px=plr(j)*cxr(j)
                      py=plr(j)*cyr(j)
                      pz=plr(j)*czr(j)
                      e=elr(j)
                      pt2=px**2+ py**2
                      tmsq=pt2+am(k)**2
c                     call kltrne(gc, -beta, e, tmsq, etran, icon)
                      call klorez(gc, -gcb, p, am, po)
                      if( pz/e .gt. .999) then
                          pt2=px**2+py**2
                          tm2=am(k)**2+pt2
                          y=log( (e+pz)/tm2 *2*pz )/2
                      else
                          y=log( (e+pz)/(e-pz))/2
                      endif
c                     if(k .eq. 13) then
c                        x=etran/epipmx
c                     elseif(k .eq. 14) then
c                        x=etran/epimmx
c                     else
c                        x=etran/epi0mx
c                     endif
                      x=e/elab
c                     write(13) float(k), x, y, sqrt(pt2)
                      write(13)  x, y, float(k)
                 endif
               enddo
           enddo
      end

==> Cosmos.uv5.60.tar.gz: Import/Test/tstaadn.f <==
caadnhadrin.  the monte carlo code hadrin to simulate inelastic hadron-
c1   nucleon interactions at laboratory energies below 5 gev.
c2  k. hanssgen, j. ranft.
cref. in comp. phys. commun. 39 (1986) 37
c   mainprogram for test of hadrin
      dimension anap(60)
      real * 8 aname,zkname,rkname,anap
      integer * 2 ich,ibar,k1,k2,nzk,nrk
      common /namsdC/ aname(110),zkname(460),rkname(268)
      common/abltisC/am(110),ga(110),tau(110),ich(110)
     *,ibar(110),k1(110),k2(110)
      common /encoteC/ etest,tnkte
      common/finlspC/ ir ,itr(20),cxr(20),cyr(20),czr(20),elr(20),plr(20)
      integer * 2 nure,ieii,ikii
      common /splitC/ nzk(460,3),wt(460)
      common /redverC/ irii(17),ikii(17),ieii(17),thresh(268)
      common /reacC/umo(296),plabf(296),siin(296),wk(5184),nrk(2,268),
     *nure(30,2)
c*** preparation of data for use in hadrin
c*** read input data
c*** n    = type of the projectile particle
c*** ia   = nucleon number of the target nucleon
c*** iz   = charge of the target nucleon
c*** plab = laboratory momentum of the projectile particle (gev/c)
c*** idifd = switch variable (=0: simulation of only one event,
      dimension nf(10)
c---- test example data input
c     data nf/1,14,2,1,6*999/
      data nf/9*25, 999/
      data iz,ia,plab /1,1,2.0/
c---- end of data input
c      character*70 ttl
c      character*16 capx, capy, capz, cappt
         external blkhd1, blkhd2, blkhd3, blkhd4
         external blkdc1, blkdc2
c      open(13,file='c2s5001.#gd.data')
c      capx='ptcl code'
c      capy='x=(e/e0)'
c      capz='lab-rapidity'
c      cappt='pt(gev/c)'
      call haddenC
      call chanwhC
c**** for the output of tables 2 to 5 only, delete therefore "c----"
c**** of the following line
c---- call datesh
c      n=13
       n=1
       plab=5.0
      elab=sqrt(plab**2+am(n)**2)
c     elab=5.0
c     plab=sqrt(elab**2-am(n)**2)
c      write(ttl,'('' plab='',f5.1,'' gev; p p; hadrin'')') plab
      pmass=am(n)
      tmass=am(1)
      call kgcm(elab, pmass, tmass, roots, gc)
      call kgtogb(gc, gcb)
      epipmx=(roots**2 -1.88**2 +am(13)**2)/2/roots
      epimmx=(roots**2 -2.02**2 +am(14)**2)/2/roots
c     epi0mx=(roots**2 -1.88**2 +am(23)**2)/2/roots
c      write(13) ttl
c      write(13) capy, capz,capx
       itta=1
          cx=0.
          cy=0.
          cz=1.
           do   i=1, 50000
              if(mod(i,1000) .eq. 0) then
                  write(*,*) ' i=',i
              endif
              call hadrinC(n,plab,elab,cx,cy,cz,itta)
               do   j=1, ir
                 k=itr(j)
c                if(k .eq. 13 .or. k.eq. 14 .or. k .eq. 23) then
                 if(k .eq. 13 .or. k.eq. 14 .or. k .eq. 23) then
                      px=plr(j)*cxr(j)
                      py=plr(j)*cyr(j)
                      pz=plr(j)*czr(j)
                      e=elr(j)
                      pt2=px**2+ py**2
                      tmsq=pt2+am(k)**2
c                     call kltrne(gc, -beta, e, tmsq, etran, icon)
                      call klorez(gc, -gcb, p, am, po)
                      if( pz/e .gt. .999) then
                          pt2=px**2+py**2
                          tm2=am(k)**2+pt2
                          y=log( (e+pz)/tm2 *2*pz )/2
                      else
                          y=log( (e+pz)/(e-pz))/2
                      endif
c                     if(k .eq. 13) then
c                        x=etran/epipmx
c                     elseif(k .eq. 14) then
c                        x=etran/epimmx
c                     else
c                        x=etran/epi0mx
c                     endif
                      x=e/elab
c                     write(13) float(k), x, y, sqrt(pt2)
                      write(13)  x, y, float(k)
                 endif
               enddo
           enddo
      end
